@@ -34,6 +34,7 @@ from bench.utils.bench import (
 )
 from bench.utils.render import job, step
 from bench.utils.app import get_current_version
+from bench.app import is_git_repo
 
 
 if TYPE_CHECKING:
@@ -43,8 +44,8 @@ logger = logging.getLogger(bench.PROJECT_NAME)
 
 
 class Base:
-	def run(self, cmd, cwd=None):
-		return exec_cmd(cmd, cwd=cwd or self.cwd)
+	def run(self, cmd, cwd=None, _raise=True):
+		return exec_cmd(cmd, cwd=cwd or self.cwd, _raise=_raise)
 
 
 class Validator:
@@ -70,7 +71,7 @@ class Bench(Base, Validator):
 
 	@property
 	def python(self) -> str:
-		return get_env_cmd("python*", bench_path=self.name)
+		return get_env_cmd("python", bench_path=self.name)
 
 	@property
 	def shallow_clone(self) -> bool:
@@ -130,9 +131,10 @@ class Bench(Base, Validator):
 		except InvalidRemoteException:
 			if not force:
 				raise
+
 		self.apps.sync()
 		# self.build() - removed because it seems unnecessary
-		self.reload()
+		self.reload(_raise=False)
 
 	@step(title="Building Bench Assets", success="Bench Assets Built")
 	def build(self):
@@ -140,16 +142,16 @@ class Bench(Base, Validator):
 		run_frappe_cmd("build", bench_path=self.name)
 
 	@step(title="Reloading Bench Processes", success="Bench Processes Reloaded")
-	def reload(self, web=False, supervisor=True, systemd=True):
+	def reload(self, web=False, supervisor=True, systemd=True, _raise=True):
 		"""If web is True, only web workers are restarted"""
 		conf = self.conf
 
 		if conf.get("developer_mode"):
 			restart_process_manager(bench_path=self.name, web_workers=web)
-		if supervisor and conf.get("restart_supervisor_on_update"):
-			restart_supervisor_processes(bench_path=self.name, web_workers=web)
+		if supervisor or conf.get("restart_supervisor_on_update"):
+			restart_supervisor_processes(bench_path=self.name, web_workers=web, _raise=_raise)
 		if systemd and conf.get("restart_systemd_on_update"):
-			restart_systemd_processes(bench_path=self.name, web_workers=web)
+			restart_systemd_processes(bench_path=self.name, web_workers=web, _raise=_raise)
 
 	def get_installed_apps(self) -> List:
 		"""Returns list of installed apps on bench, not in excluded_apps.txt"""
@@ -222,21 +224,28 @@ class BenchApps(MutableSequence):
 			version = get_current_version(app_name, self.bench.name)
 
 			app_dir = os.path.join(self.apps_path, app_dir)
-			if not branch:
-				branch = (
-					subprocess.check_output("git rev-parse --abbrev-ref HEAD", shell=True, cwd=app_dir)
+			is_repo = is_git_repo(app_dir)
+			if is_repo:
+				if not branch:
+					branch = (
+						subprocess.check_output(
+							"git rev-parse --abbrev-ref HEAD", shell=True, cwd=app_dir
+						)
+						.decode("utf-8")
+						.rstrip()
+					)
+
+				commit_hash = (
+					subprocess.check_output(f"git rev-parse {branch}", shell=True, cwd=app_dir)
 					.decode("utf-8")
 					.rstrip()
 				)
 
-			commit_hash = (
-				subprocess.check_output(f"git rev-parse {branch}", shell=True, cwd=app_dir)
-				.decode("utf-8")
-				.rstrip()
-			)
-
 			self.states[app_name] = {
-				"resolution": {"commit_hash": commit_hash, "branch": branch},
+				"is_repo": is_repo,
+				"resolution": "not a repo"
+				if not is_repo
+				else {"commit_hash": commit_hash, "branch": branch},
 				"required": required,
 				"idx": len(self.states) + 1,
 				"version": version,
@@ -301,13 +310,13 @@ class BenchApps(MutableSequence):
 	def add(self, app: "App"):
 		app.get()
 		app.install()
-		super().append(app.repo)
+		super().append(app.app_name)
 		self.apps.sort()
 
 	def remove(self, app: "App", no_backup: bool = False):
 		app.uninstall()
 		app.remove(no_backup=no_backup)
-		super().remove(app.repo)
+		super().remove(app.app_name)
 
 	def append(self, app: "App"):
 		return self.add(app)
@@ -353,6 +362,7 @@ class BenchSetup(Base):
 			self.run(f"{venv} env", cwd=self.bench.name)
 
 		self.pip()
+		self.wheel()
 
 		if os.path.exists(frappe):
 			self.run(
@@ -361,12 +371,12 @@ class BenchSetup(Base):
 			)
 
 	@step(title="Setting Up Bench Config", success="Bench Config Set Up")
-	def config(self, redis=True, procfile=True):
+	def config(self, redis=True, procfile=True, additional_config=None):
 		"""Setup config folder
 		- create pids folder
 		- generate sites/common_site_config.json
 		"""
-		setup_config(self.bench.name)
+		setup_config(self.bench.name, additional_config=additional_config)
 
 		if redis:
 			from bench.config.redis import generate_config
@@ -390,6 +400,19 @@ class BenchSetup(Base):
 			f"{self.bench.python} -m pip install {quiet_flag} --upgrade pip", cwd=self.bench.name
 		)
 
+	@step(title="Installing wheel", success="Installed wheel")
+	def wheel(self, verbose=False):
+		"""Wheel is required for building old setup.py packages.
+		ref: https://github.com/pypa/pip/issues/8559"""
+		import bench.cli
+
+		verbose = bench.cli.verbose or verbose
+		quiet_flag = "" if verbose else "--quiet"
+
+		return self.run(
+			f"{self.bench.python} -m pip install {quiet_flag} wheel", cwd=self.bench.name
+		)
+
 	def logging(self):
 		from bench.utils import setup_logging
 
